import { DateTime } from "luxon";
export declare enum UNIT {
    YEAR = "year",
    MONTH = "month",
    WEEK = "week",
    DAY = "day"
}
export interface ConstructorParams {
    year: number;
    month: number;
    day: number;
}
export interface OptionalParams {
    year?: number;
    month?: number;
    day?: number;
}
export declare class Date {
    dateTime: DateTime;
    /**
     * Constructor
     * @param params year, month, day
     */
    constructor(params?: ConstructorParams);
    /**
     * Constructor
     * @param date time string ex) "2022-03-14"
     * @returns Date
     */
    static string(date: string): Date;
    /**
     * @returns luxon datetime
     */
    getDateTime(): DateTime;
    /**
     * @returns year of date
     */
    getYear(): number;
    /**
     * @returns month of date
     */
    getMonth(): number;
    /**
     * @returns weekday of date
     */
    getWeekday(): number;
    /**
     * @returns weeknumber of date
     */
    getWeekNumber(): number;
    /**
     * @returns day of date
     */
    getDay(): number;
    /**
     * @param unit year, month, week, day
     * @returns start of the unit
     */
    getStart(unit: UNIT): DateTime;
    /**
     * @param unit year, month, week, day
     * @returns end of the unit
     */
    getEnd(unit: UNIT): DateTime;
    /**
     * @param year year to set
     * @param month month to set
     * @param day day to set
     */
    set({ year, month, day }: OptionalParams): void;
    /**
     * @param year year to add
     * @param month month to add
     * @param day day to add
     */
    plus({ year, month, day }: OptionalParams): void;
    /**
     * @param date date to compare
     * @returns is euqal date
     */
    isEqual(date: Date): boolean;
    /**
     * @returns date string ex) "2022-03-14"
     */
    getString(): string;
}
export interface getCalendarParams {
    date: Date;
    mondayFirst?: boolean;
}
export declare const getCalendarDate: ({ date, mondayFirst, }: getCalendarParams) => Array<Date>;
