"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rippleEffect = exports.getDefaultColor = exports.getPrimaryColor = exports.getColorByStatus = void 0;
var getColorByStatus = function (props) {
    return props.active ? (0, exports.getPrimaryColor)(props) : (0, exports.getDefaultColor)(props);
};
exports.getColorByStatus = getColorByStatus;
var getPrimaryColor = function (props) {
    var _a, _b;
    if ("primaryColor" in props)
        return (_a = props.primaryColor) !== null && _a !== void 0 ? _a : "gray";
    return (_b = props.theme.primaryColor) !== null && _b !== void 0 ? _b : "gray";
};
exports.getPrimaryColor = getPrimaryColor;
var getDefaultColor = function (props) {
    var _a, _b;
    if ("defaultColor" in props)
        return (_a = props.defaultColor) !== null && _a !== void 0 ? _a : "gray";
    return (_b = props.theme.defaultColor) !== null && _b !== void 0 ? _b : "gray";
};
exports.getDefaultColor = getDefaultColor;
/**
 * Generate Ripple Effect at Button Click
 * @param event
 * @param theme
 * @param primary
 */
var rippleEffect = function (event, theme, primary) {
    var button = event.currentTarget;
    // create container for circle
    var container = document.createElement("div");
    container.style.width = "".concat(button.offsetWidth, "px");
    container.style.height = "".concat(button.offsetHeight, "px");
    container.style.borderRadius = "inherit";
    container.classList.add("container");
    // create circle
    var circle = document.createElement("span");
    var diameter = Math.max(button.clientWidth, button.clientHeight);
    var radius = diameter / 2;
    circle.style.width = circle.style.height = "".concat(diameter, "px");
    circle.style.top = "".concat(event.nativeEvent.offsetY - radius, "px");
    circle.style.left = "".concat(event.nativeEvent.offsetX - radius, "px");
    circle.style.backgroundColor = primary ? (0, exports.getPrimaryColor)(theme) : "#fff";
    circle.style.opacity = primary ? "0.3" : "1";
    circle.classList.add("ripple");
    // remove container, if already exist ripple
    var ripple = button.getElementsByClassName("container")[0];
    if (ripple) {
        ripple.remove();
    }
    // append ripple to button inside
    container.appendChild(circle);
    button.appendChild(container);
};
exports.rippleEffect = rippleEffect;
