export declare enum TIMES_OF_DAY {
    AM = "AM",
    PM = "PM"
}
export declare enum UNIT {
    TIMES_OF_DAY = "times",
    HOUR = "hour",
    MIN = "min",
    SECONDS = "seconds"
}
export declare const HOURS: readonly [12, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
export interface ConstructorParams {
    hour?: number;
    min?: number;
    seconds?: number;
}
declare type SetTimeAction = number | ((prev: number) => number);
interface getStringParams {
    show24Hour?: boolean;
    showSeconds?: boolean;
}
export declare class Time {
    passed: number;
    /**
     * Constructor
     * @param params hour, min, seconds
     */
    constructor(params: ConstructorParams);
    /**
     * Constructor
     * @param time time string ex) "09:00:00"
     * @returns Time
     */
    static string(time: string): Time;
    /**
     * Constructor
     * @param passed total of the passed time in seconds
     * @returns Time
     */
    static passed(passed: number): Time;
    /**
     * @returns Get whether it is AM or PM.
     */
    getTimesOfDay(): TIMES_OF_DAY;
    /**
     * @returns hour
     */
    getHour(): number;
    /**
     * @returns minute
     */
    getMin(): number;
    /**
     * @returns seconds
     */
    getSeconds(): number;
    /**
     * @returns total of the passed time in hour
     */
    getHourPassed(): number;
    /**
     * @returns total of the passed time in minute
     */
    getMinPassed(): number;
    /**
     * @returns total of the passed time in seconds
     */
    getSecondsPassed(): number;
    /**
     * @param action hour to set
     */
    setHour(action: SetTimeAction, timesOfDay?: TIMES_OF_DAY): void;
    /**
     * @param action minute to set
     */
    setMin(action: SetTimeAction): void;
    /**
     * @param action seconds to set
     */
    setSeconds(action: SetTimeAction): void;
    /**
     * @param passed total of the passed time in seconds to set
     */
    setPassed(passed: number): void;
    /**
     * @param hours hour to add
     * @param min minute to add
     * @param seconds seconds to add
     */
    plus({ hour, min, seconds }: ConstructorParams): void;
    /**
     * @param show24Hour show in 24 hours
     * @param showSeconds show seconds in string
     * @returns time string ex) "09:00:00"
     */
    getString({ show24Hour, showSeconds }: getStringParams): string;
}
export {};
